@@ -678,16 +678,112 @@ class ComparisonTab(QWidget):
         # Connect worker signals
         worker.progress_updated.connect(self.update_run_progress)
         worker.topics_extracted.connect(
-            lambda topics, probs, topics_words, topic_info, model: 
+            lambda topics, probs, topics_words, topic_info, model, chunked_docs: 
             self.on_run_complete(run_config, topics, probs, topics_words, topic_info, model, run_index)
         )
         worker.error_occurred.connect(
             lambda error: self.on_run_error(error, run_config, run_index)
         )
         
+        # Connect the show_elbow_dialog signal to our new handler
+        worker.show_elbow_dialog.connect(
+            lambda model_scores, topics_range: 
+            self.handle_elbow_dialog(worker, model_scores, topics_range)
+        )
+        
         # Forward progress updates
         worker.progress_updated.connect(self.progress_updated)
-    
+
+    def handle_elbow_dialog(self, worker, model_scores, topics_range):
+        """Handle the elbow method dialog for LDA topic selection"""
+        # Create a dialog for the elbow method
+        dialog = QDialog(self)
+        dialog.setWindowTitle("LDA Elbow Method - Select Optimal Number of Topics")
+        dialog.setMinimumSize(600, 500)
+        
+        layout = QVBoxLayout(dialog)
+        layout.setSpacing(WIDGET_SPACING)
+        layout.setContentsMargins(LAYOUT_MARGIN, LAYOUT_MARGIN, LAYOUT_MARGIN, LAYOUT_MARGIN)
+        
+        # Add description label
+        description = QLabel(
+            "The elbow method helps find the optimal number of topics. "
+            "Look for the 'elbow' point where adding more topics gives diminishing returns."
+        )
+        description.setWordWrap(True)
+        layout.addWidget(description)
+        
+        # Create figure for the elbow plot
+        fig, ax = plt.subplots(figsize=(8, 6))
+        ax.plot(topics_range, model_scores, marker='o', linewidth=2)
+        ax.set_xlabel('Number of Topics')
+        ax.set_ylabel('Model Score')
+        ax.set_title('LDA Topic Model Performance')
+        ax.grid(True)
+        
+        # Create canvas for the plot
+        canvas = FigureCanvas(fig)
+        canvas.setMinimumHeight(350)
+        layout.addWidget(canvas)
+        
+        # Add a form for selecting the number of topics
+        form_layout = QHBoxLayout()
+        form_layout.addWidget(QLabel("Select number of topics:"))
+        
+        # Spinbox for selecting number of topics
+        topic_spinbox = QSpinBox()
+        topic_spinbox.setRange(min(topics_range), max(topics_range))
+        
+        # Try to find the elbow point and set it as default
+        try:
+            # If available, use scipy to find local minima/maxima
+            from scipy.signal import argrelextrema
+            import numpy as np
+            
+            # Convert to numpy array for processing
+            scores_array = np.array(model_scores)
+            
+            # Find the maximum score (often a good choice for default)
+            max_index = np.argmax(scores_array)
+            default_topics = topics_range[max_index]
+            
+        except Exception as e:
+            # If any error occurs, just use the midpoint
+            default_topics = topics_range[len(topics_range) // 2]
+        
+        topic_spinbox.setValue(default_topics)
+        form_layout.addWidget(topic_spinbox)
+        layout.addLayout(form_layout)
+        
+        # Add buttons
+        button_layout = QHBoxLayout()
+        cancel_button = QPushButton("Cancel")
+        cancel_button.clicked.connect(lambda: self.on_elbow_dialog_closed(dialog, worker, None))
+        cancel_button.setMinimumHeight(BUTTON_HEIGHT)
+        button_layout.addWidget(cancel_button)
+        
+        select_button = QPushButton("Select")
+        select_button.clicked.connect(lambda: self.on_elbow_dialog_closed(dialog, worker, topic_spinbox.value()))
+        select_button.setDefault(True)
+        select_button.setMinimumHeight(BUTTON_HEIGHT)
+        button_layout.addWidget(select_button)
+        layout.addLayout(button_layout)
+        
+        # Show the dialog - using exec_ to make it modal
+        dialog.exec_()
+
+    def on_elbow_dialog_closed(self, dialog, worker, result):
+        """Handle the closing of the elbow dialog"""
+        # Close the dialog
+        dialog.close()
+        
+        if result is None:
+            # User canceled, set the cancellation flag
+            worker.elbow_selection_cancelled = True
+        else:
+            # Set the result in the worker
+            worker.elbow_selection_result = result
+            
     @pyqtSlot(int, str)
     def update_run_progress(self, progress, message):
         """Update progress bar for the current run"""
